Provides helpers for selecting a network interface on the current host through which to preform network scanning, and for detecting the default gateway from the OS routing table.
Structs
- Network
Interface - Represents a network interface on current host
Functions
- get_
available_ port - Finds an available port on the current host. This is useful when setting the listening port on a scanner where packets will be received.
- get_
default_ gateway - Returns the default gateway IPv4 address by parsing the system routing
table. Works on Linux (
ip route show). ReturnsNoneif the gateway cannot be determined. - get_
default_ interface - Finds and returns the default NetworkInterface for current host
- get_
interface - Finds and returns a NetworkInterface by name for current host