pub struct OuiDb { /* private fields */ }Expand description
In-memory OUI database backed by locally cached IEEE CSV files.
Implementations
Sourceimpl OuiDb
impl OuiDb
Sourcepub fn new(data_dir: &Path) -> Self
pub fn new(data_dir: &Path) -> Self
Creates a new OuiDb pointing at data_dir for cached CSV files.
Sourcepub fn age(&self) -> Option<SystemTime>
pub fn age(&self) -> Option<SystemTime>
Returns the modification time of the oldest cached CSV file,
or None if any file is missing or its mtime is unavailable.