pub struct FullScannerBuilder { /* private fields */ }Expand description
Builder for FullScanner.
Implementations
Sourceimpl FullScannerBuilder
impl FullScannerBuilder
Sourcepub fn interface<VALUE: Into<Arc<NetworkInterface>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn interface<VALUE: Into<Arc<NetworkInterface>>>( &mut self, value: VALUE, ) -> &mut Self
Network interface to use for scanning
Sourcepub fn wire<VALUE: Into<Wire>>(&mut self, value: VALUE) -> &mut Self
pub fn wire<VALUE: Into<Wire>>(&mut self, value: VALUE) -> &mut Self
Wire for reading and sending packets on the wire
Sourcepub fn targets<VALUE: Into<Arc<IPTargets>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn targets<VALUE: Into<Arc<IPTargets>>>( &mut self, value: VALUE, ) -> &mut Self
IP targets to scan for device discovery
Sourcepub fn ports<VALUE: Into<Arc<PortTargets>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn ports<VALUE: Into<Arc<PortTargets>>>( &mut self, value: VALUE, ) -> &mut Self
Port targets to scan on discovered devices
Sourcepub fn vendor<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn vendor<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether to include vendor lookups for discovered devices
Sourcepub fn host<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn host<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether to include hostname lookups for discovered devices
Sourcepub fn idle_timeout<VALUE: Into<Duration>>(&mut self, value: VALUE) -> &mut Self
pub fn idle_timeout<VALUE: Into<Duration>>(&mut self, value: VALUE) -> &mut Self
Duration to wait for responses after scanning completes
Sourcepub fn throttle<VALUE: Into<Duration>>(&mut self, value: VALUE) -> &mut Self
pub fn throttle<VALUE: Into<Duration>>(&mut self, value: VALUE) -> &mut Self
Throttles speed at which packets are sent. Higher throttles result in more accurate scans
Sourcepub fn notifier<VALUE: Into<Sender<ScanMessage>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn notifier<VALUE: Into<Sender<ScanMessage>>>( &mut self, value: VALUE, ) -> &mut Self
Channel for sending scan results and status messages
Sourcepub fn source_port<VALUE: Into<u16>>(&mut self, value: VALUE) -> &mut Self
pub fn source_port<VALUE: Into<u16>>(&mut self, value: VALUE) -> &mut Self
Source port for packet listener and incoming packet identification
Sourcepub fn oui<VALUE: Into<Option<Arc<dyn Oui>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn oui<VALUE: Into<Option<Arc<dyn Oui>>>>( &mut self, value: VALUE, ) -> &mut Self
Used to lookup vendor info for mac addresses
Sourcepub fn build(&self) -> Result<FullScanner, FullScannerBuilderError>
pub fn build(&self) -> Result<FullScanner, FullScannerBuilderError>